.. _djblets-guides:

======
Guides
======

.. toctree::
   :maxdepth: 2

   avatars/index
   extensions/index
   features/index
   integrations/index
   recaptcha/index
   registries/index
   webapi/index
